@@ -6,7 +6,7 @@
 #
 #   28-May-2020 jdw use alternative url fetch library.
 ##
-__docformat__ = "google.en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "jwest@rcsb.rutgers.edu"
 __license__ = "Apache 2.0"
